<?php
/**
* @package wp-pagalocard-woocommerce
* @author XicoOfficial
* @since 1.1.0
 */

class wowp_pcwpg_pagalocard extends WC_Payment_Gateway {

	function __construct() {

		// global ID
		$this->id = "wowp_pcwpg_pagalocard";

		// Show Title
		$this->method_title = __( "Pagalo Card", 'wp-pagalocard-woocommerce' );

		// Show Description
		$this->method_description = __( "Pagalo Card Payment Gateway Plug-in for WooCommerce", 'wp-pagalocard-woocommerce' );

		// vertical tab title
		$this->title = __( "Pagalo Card", 'wp-pagalocard-woocommerce' );


		$this->icon = null;

		$this->has_fields = true;

		// support default form with credit card
		$this->supports = array( 'default_credit_card_form' );

		// setting defines
		$this->init_form_fields();

		// load time variable setting
		$this->init_settings();
		
		// Turn these settings into variables we can use
		foreach ( $this->settings as $setting_key => $value ) {
			$this->$setting_key = $value;
		}
		
		// further check of SSL if you want
		add_action( 'admin_notices', array( $this,	'do_ssl_check' ) );
		
		// Save settings
		if ( is_admin() ) {
			add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'process_admin_options' ) );
		}		
	} // Here is the  End __construct()

	// administration fields for specific Gateway
	public function init_form_fields() {
		$this->form_fields = array(
			'enabled' => array(
				'title'			=> __( 'Enable / Disable', 'wp-pagalocard-woocommerce' ),
				'label'			=> __( 'Enable this payment gateway', 'wp-pagalocard-woocommerce' ),
				'type'			=> 'checkbox',
				'default'		=> 'no',
			),
			'title' => array(
				'title'			=> __( 'Title', 'wp-pagalocard-woocommerce' ),
				'type'			=> 'text',
				'desc_tip'	=> __( 'Payment title of checkout process.', 'wp-pagalocard-woocommerce' ),
				'default'		=> __( 'Credit card', 'wp-pagalocard-woocommerce' ),
			),
			'description' => array(
				'title'			=> __( 'Description', 'wp-pagalocard-woocommerce' ),
				'type'			=> 'textarea',
				'desc_tip'	=> __( 'Payment title of checkout process.', 'wp-pagalocard-woocommerce' ),
				'default'		=> __( 'Successfully payment through credit card.', 'wp-pagalocard-woocommerce' ),
				'css'				=> 'max-width:450px;'
			),
			'pc_idenEmpresa' => array(
				'title'			=> __( 'IdemEmpresa', 'wp-pagalocard-woocommerce' ),
				'type'			=> 'text',
				'desc_tip'	=> __( 'This is the IdemEmpresa provided by PagaloCard when you signed up for an account.', 'wp-pagalocard-woocommerce' ),
			),
			'pc_token' => array(
				'title'			=> __( 'Token', 'wp-pagalocard-woocommerce' ),
				'type'			=> 'text',
				'desc_tip'	=> __( 'This is the Token provided by PagaloCard when you signed up for an account.', 'wp-pagalocard-woocommerce' ),
			),
			'pc_key_public' => array(
				'title'			=> __( 'API Public Key', 'wp-pagalocard-woocommerce' ),
				'type'			=> 'text',
				'desc_tip'	=> __( 'This is the Public Key provided by PagaloCard when you signed up for an account.', 'wp-pagalocard-woocommerce' ),
			),
			'pc_key_secret' => array(
				'title'			=> __( 'API Secret Key', 'wp-pagalocard-woocommerce' ),
				'type'			=> 'text',
				'desc_tip'	=> __( 'This is the API Secret Key provided by PagaloCard when you signed up for an account.', 'wp-pagalocard-woocommerce' ),
			),
			'environment' => array(
				'title'			=> __( 'PagaloCard Test Mode', 'wp-pagalocard-woocommerce' ),
				'label'			=> __( 'Enable Test Mode', 'wp-pagalocard-woocommerce' ),
				'type'			=> 'checkbox',
				'description' => __( 'This is the test mode of gateway.', 'wp-pagalocard-woocommerce' ),
				'default'		=> 'no',
			)
		);		
	}
	
	// Response handled for payment gateway
	public function process_payment( $order_id ) {
		global $woocommerce;

		$customer_order = new WC_Order( $order_id );

		$products = $customer_order->get_items();
		
		// checking for transiction
		$environment = ( $this->environment == "yes" ) ? 'TRUE' : 'FALSE';

		// Decide which URL to post to
		$environment_url = ( "FALSE" == $environment ) ? 'https://app.pagalocard.com/api/v1/integracion/' . $this->pc_token : 'https://sandbox.pagalocard.com/api/v1/integracion/' . $this->pc_token;



		$empresa= array(
		'key_secret'=> $this->pc_key_secret,
		'key_public'=> $this->pc_key_public,
		'idenEmpresa'=> $this->pc_idenEmpresa,
		);

		$cliente= array(
			'firstName' => mb_convert_encoding($customer_order->billing_first_name, 'HTML-ENTITIES'),
			'lastName'  => mb_convert_encoding($customer_order->billing_last_name, 'HTML-ENTITIES'),
			'street1'		=> $customer_order->billing_address_1,
			'phone'			=> $customer_order->billing_phone,
			'country'		=> $customer_order->billing_country,
			'city'			=> $customer_order->billing_city,
			'state'			=> $customer_order->billing_state,
			'postalCode'=> $customer_order->billing_postcode,
			'email'			=> $customer_order->billing_email,
			'ipAddress'	=>  $_SERVER['REMOTE_ADDR'],
			'Total'			=> $customer_order->total,
			'fecha_transaccion'=> $customer_order->date_created,
			'currency'	=> $customer_order->currency,
		  'deviceFingerprintID' => '',
		);


		$detalle=[];

		foreach ( $products as $product ) {
    	$detalle[] = array(
				'id_producto'	=> $product->get_product_id(),
				'cantidad'		=> $product->get_quantity(),
				'tipo'				=> $product->get_type(),
				'nombre'			=> $product->get_name(),
				'precio'			=> get_post_meta( $product->get_product_id(), '_regular_price', true),
				'Subtotal'		=> $product->get_total(),
			);
		}

		$date_array = $_POST['wowp_pcwpg_pagalocard-card-expiry'];
		$date_array = explode("/", str_replace(' ', '', $date_array));

		$tarjetaPagalo = array(
				'nameCard'				=> mb_convert_encoding($_POST['wowp_pcwpg_pagalocard-card-name'], 'HTML-ENTITIES'),
				'accountNumber'		=> str_replace( array(' ', '-' ), '', $_POST['wowp_pcwpg_pagalocard-card-number'] ),
				'expirationMonth'	=> $date_array[0],
				'expirationYear'	=> $date_array[1], 
				'CVVCard'					=> ( isset( $_POST['wowp_pcwpg_pagalocard-card-cvc'] ) ) ? $_POST['wowp_pcwpg_pagalocard-card-cvc'] : 'no',
		);


		$str_empresa = json_encode($empresa);

		$str_cliente = json_encode($cliente);

		$str_detalle = json_encode($detalle);

		$str_tarjeta = json_encode($tarjetaPagalo);

		$data=array('empresa' => $str_empresa, 'cliente' => $str_cliente, 'detalle' => $str_detalle, 'tarjetaPagalo' => $str_tarjeta);

    $str_data = json_encode($data); 
 
    $ch = curl_init($environment_url); 
 
    //Tell cURL that we want to send a POST request. 
    curl_setopt($ch, CURLOPT_POST, 1); 
      
    //Attach our encoded JSON string to the POST fields. 
    curl_setopt($ch, CURLOPT_POSTFIELDS, $str_data); 
      
    //Set the content type to application/json 
    curl_setopt($ch, CURLOPT_HTTPHEADER, array('Content-Type: application/json'));  
 
    // Return information 
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1); 
      
    //Execute the request 
    $result = curl_exec($ch); 
 
    var_dump($result); 
 
    $result = json_decode($result, true); 

		if ( is_wp_error( $result ) ) {
					throw new Exception( __( 'There is issue for connectin payment gateway. Sorry for the inconvenience.', 'wp-pagalocard-woocommerce' ) );
				if ( empty( $result['respuesta'] ) ) {
					throw new Exception( __( 'PagaloCard\'s Response was not get any data.', 'wp-pagalocard-woocommerce' ) );	
				}
		}

		$error_message = $result['decision'];

		// 100 o 200 means the transaction was a success
		if ( ( $result['reasonCode'] == 200 ) || $result['reasonCode'] == 100) {
			// Payment successful
			$customer_order->add_order_note( __( 'PagaloCard complete payment.', 'wp-pagalocard-woocommerce' ) );
												 
			// paid order marked
			$customer_order->payment_complete();
			// this is important part for empty cart
			$woocommerce->cart->empty_cart();
			// Redirect to thank you page
			return array(
				'result'   => 'success',
				'redirect' => $this->get_return_url( $customer_order ),
			);
		} else {
			//transiction fail
			wc_add_notice( 'Error:' . $error_message . ' - Error Code: ' . $result['reasonCode'], 'error' ); 
			$customer_order->add_order_note( 'Error: '. $result['decision'] );

		}

	}
	
	// Validate fields
	public function validate_fields() {
		return true;
	}

	public function do_ssl_check() {
		if( $this->enabled == "yes" ) {
			if( get_option( 'woocommerce_force_ssl_checkout' ) == "no" ) {
				echo "<div class=\"error\"><p>". sprintf( __( "<strong>%s</strong> is enabled and WooCommerce is not forcing the SSL certificate on your checkout page. Please ensure that you have a valid SSL certificate and that you are <a href=\"%s\">forcing the checkout pages to be secured.</a>", 'wp-pagalocard-woocommerce' ), $this->method_title, admin_url( 'admin.php?page=wc-settings&tab=checkout' ) ) ."</p></div>";	
			}
		}		
	}

}