<?php 
/**
* @since 1.0.0
* @package wp-pagalocard-woocommerce
* @author xicoofficial
* 
* Plugin Name: Pagalo Card - WooCommerce Payment Gateway
* Plugin URI: https://wordpress.org/plugins/wp-pagalocard-woocommerce/
* Description: WooCommerce custom payment gateway integration with PagaloCard.
* Version: 1.1.1
* Author: XicoOfficial
* Author URI: https://profiles.wordpress.org/xicoofficial
* Licence: GPL-3.0+
* Text Domain: wp-pagalocard-woocommerce
* Domain Path: /languages/
*/
 

/**
 * Tell WordPress to load a translation file if it exists for the user's language
 */
function wowp_pcwpg_load_plugin_textdomain() {
    load_plugin_textdomain( 'wp-pagalocard-woocommerce', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
}

add_action( 'plugins_loaded', 'wowp_pcwpg_load_plugin_textdomain' );


function wowp_pcwpg_pagalocard_init() {
    //if condition use to do nothin while WooCommerce is not installed
	if ( ! class_exists( 'WC_Payment_Gateway' ) ) return;
	include_once( 'wp-pagalocard-woocommerce-admin.php' );
	// class add it too WooCommerce
	add_filter( 'woocommerce_payment_gateways', 'wowp_pcwpg_add_pagalocard_gateway' );
	function wowp_pcwpg_add_pagalocard_gateway( $methods ) {
		$methods[] = 'wowp_pcwpg_pagalocard';
		return $methods;
	}
}

add_action( 'plugins_loaded', 'wowp_pcwpg_pagalocard_init', 0 );


/**
* Add custom action links
*/
function wowp_pcwpg_pagalocard_action_links( $links ) {
	$plugin_links = array(
		'<a href="' . admin_url( 'admin.php?page=wc-settings&tab=checkout' ) . '">' . __( 'Settings', 'wp-pagalocard-woocommerce' ) . '</a>',
	);
	return array_merge( $plugin_links, $links );
}

add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'wowp_pcwpg_pagalocard_action_links' );


/**
* Customize credict card form
*/
function wowp_pcwpg_pagalocard_custom_credit_card_fields ($cc_fields , $payment_id){
	$new_fields = array(
	 'card-name-field' => '<p class="form-row form-row-wide"><label for="' . esc_attr( $payment_id ) . '-card-name">'
	 		. __( 'Cardholder Name', 'wp-pagalocard-woocommerce' ) . ' <span class="required">*</span>
	 	</label>
	 	<input id="' . esc_attr( $payment_id ) . '-card-name" class="input-text wc-credit-card-form-card-name" type="text" maxlength="30" autocomplete="off" placeholder="CARDHOLDER NAME" name="' . esc_attr( $payment_id ) . '-card-name' . '" />
	 </p>'
	);

	$cc_fields = $new_fields + $cc_fields;

	return $cc_fields;
}

add_filter( 'woocommerce_credit_card_form_fields' , 'wowp_pcwpg_pagalocard_custom_credit_card_fields' , 10, 2 );
